# Table of Contents

- [download-reports](<./download-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Downloading Reports from the SAP LeanIX Store](<./Downloading-Reports-from-the-SAP-LeanIX-Store.md>)
  - [Introduction to the SAP LeanIX Store](<./Downloading-Reports-from-the-SAP-LeanIX-Store/Introduction-to-the-SAP-LeanIX-Store.md>)
  - [Downloading a Report](<./Downloading-Reports-from-the-SAP-LeanIX-Store/Downloading-a-Report.md>)
  - [Activating a Report](<./Downloading-Reports-from-the-SAP-LeanIX-Store/Activating-a-Report.md>)
